==> v21.04.tar.gz: bookstack/resources/lang/it/common.php <==
<?php
/**
 * Common elements found throughout many areas of BookStack.
 */
return [

    // Buttons
    'cancel' => 'Annulla',
    'confirm' => 'Conferma',
    'back' => 'Indietro',
    'save' => 'Salva',
    'continue' => 'Continua',
    'select' => 'Seleziona',
    'toggle_all' => 'Attiva/disattiva tutto',
    'more' => 'Altro',

    // Form Labels
    'name' => 'Nome',
    'description' => 'Descrizione',
    'role' => 'Ruolo',
    'cover_image' => 'Immagine di copertina',
    'cover_image_description' => 'Questa immagine dovrebbe essere approssimatamente 440x250px.',
    
    // Actions
    'actions' => 'Azioni',
    'view' => 'Visualizza',
    'view_all' => 'Vedi tutto',
    'create' => 'Crea',
    'update' => 'Aggiorna',
    'edit' => 'Modifica',
    'sort' => 'Ordina',
    'move' => 'Muovi',
    'copy' => 'Copia',
    'reply' => 'Rispondi',
    'delete' => 'Elimina',
    'delete_confirm' => 'Confirm Deletion',
    'search' => 'Cerca',
    'search_clear' => 'Pulisci Ricerca',
    'reset' => 'Azzera',
    'remove' => 'Rimuovi',
    'add' => 'Aggiungi',
    'fullscreen' => 'Schermo intero',

    // Sort Options
    'sort_options' => 'Opzioni Ordinamento',
    'sort_direction_toggle' => 'Inverti Direzione Ordinamento',
    'sort_ascending' => 'Ordine Ascendente',
    'sort_descending' => 'Ordine Discendente',
    'sort_name' => 'Nome',
    'sort_default' => 'Default',
    'sort_created_at' => 'Data Creazione',
    'sort_updated_at' => 'Data Aggiornamento',

    // Misc
    'deleted_user' => 'Utente Eliminato',
    'no_activity' => 'Nessuna attività da mostrare',
    'no_items' => 'Nessun elemento disponibile',
    'back_to_top' => 'Torna in alto',
    'toggle_details' => 'Mostra Dettagli',
    'toggle_thumbnails' => 'Mostra Miniature',
    'details' => 'Dettagli',
    'grid_view' => 'Visualizzazione Griglia',
    'list_view' => 'Visualizzazione Lista',
    'default' => 'Predefinito',
    'breadcrumb' => 'Navigazione',

    // Header
    'profile_menu' => 'Menu del profilo',
    'view_profile' => 'Visualizza Profilo',
    'edit_profile' => 'Modifica Profilo',
    'dark_mode' => 'Modalità Scura',
    'light_mode' => 'Modalità Chiara',

    // Layout tabs
    'tab_info' => 'Info',
    'tab_content' => 'Contenuto',

    // Email Content
    'email_action_help' => 'Se hai problemi nel cliccare il pulsante ":actionText", copia e incolla lo URL sotto nel tuo browser:',
    'email_rights' => 'Tutti i diritti riservati',

    // Footer Link Options
    // Not directly used but available for convenience to users.
    'privacy_policy' => 'Privacy Policy',
    'terms_of_service' => 'Terms of Service',
];

==> v21.05.tar.gz: bookstack/resources/lang/it/common.php <==
<?php
/**
 * Common elements found throughout many areas of BookStack.
 */
return [

    // Buttons
    'cancel' => 'Annulla',
    'confirm' => 'Conferma',
    'back' => 'Indietro',
    'save' => 'Salva',
    'continue' => 'Continua',
    'select' => 'Seleziona',
    'toggle_all' => 'Attiva/disattiva tutto',
    'more' => 'Altro',

    // Form Labels
    'name' => 'Nome',
    'description' => 'Descrizione',
    'role' => 'Ruolo',
    'cover_image' => 'Immagine di copertina',
    'cover_image_description' => 'Questa immagine dovrebbe essere approssimativamente 440x250px.',
    
    // Actions
    'actions' => 'Azioni',
    'view' => 'Visualizza',
    'view_all' => 'Vedi tutto',
    'create' => 'Crea',
    'update' => 'Aggiorna',
    'edit' => 'Modifica',
    'sort' => 'Ordina',
    'move' => 'Muovi',
    'copy' => 'Copia',
    'reply' => 'Rispondi',
    'delete' => 'Elimina',
    'delete_confirm' => 'Conferma Eliminazione',
    'search' => 'Cerca',
    'search_clear' => 'Pulisci Ricerca',
    'reset' => 'Azzera',
    'remove' => 'Rimuovi',
    'add' => 'Aggiungi',
    'fullscreen' => 'Schermo intero',
    'favourite' => 'Favourite',
    'unfavourite' => 'Unfavourite',
    'next' => 'Next',
    'previous' => 'Previous',

    // Sort Options
    'sort_options' => 'Opzioni Ordinamento',
    'sort_direction_toggle' => 'Inverti Direzione Ordinamento',
    'sort_ascending' => 'Ordine Ascendente',
    'sort_descending' => 'Ordine Discendente',
    'sort_name' => 'Nome',
    'sort_default' => 'Predefinito',
    'sort_created_at' => 'Data Creazione',
    'sort_updated_at' => 'Data Aggiornamento',

    // Misc
    'deleted_user' => 'Utente Eliminato',
    'no_activity' => 'Nessuna attività da mostrare',
    'no_items' => 'Nessun elemento disponibile',
    'back_to_top' => 'Torna in alto',
    'toggle_details' => 'Mostra Dettagli',
    'toggle_thumbnails' => 'Mostra Miniature',
    'details' => 'Dettagli',
    'grid_view' => 'Visualizzazione Griglia',
    'list_view' => 'Visualizzazione Lista',
    'default' => 'Predefinito',
    'breadcrumb' => 'Navigazione',

    // Header
    'header_menu_expand' => 'Espandi Menù Intestazione',
    'profile_menu' => 'Menù del profilo',
    'view_profile' => 'Visualizza Profilo',
    'edit_profile' => 'Modifica Profilo',
    'dark_mode' => 'Modalità Scura',
    'light_mode' => 'Modalità Chiara',

    // Layout tabs
    'tab_info' => 'Info',
    'tab_info_label' => 'Tab: Mostra Informazioni Secondarie',
    'tab_content' => 'Contenuto',
    'tab_content_label' => 'Tab: Mostra Contenuto Principale',

    // Email Content
    'email_action_help' => 'Se hai problemi nel cliccare il pulsante ":actionText", copia e incolla lo URL sotto nel tuo browser:',
    'email_rights' => 'Tutti i diritti riservati',

    // Footer Link Options
    // Not directly used but available for convenience to users.
    'privacy_policy' => 'Norme sulla privacy',
    'terms_of_service' => 'Condizioni del Servizio',
];
